==> zio-aws-directconnect_2.12-5.17.158.3-sources.jar: zio/aws/directconnect/model/CreateDirectConnectGatewayAssociationProposalResponse.scala <==
package zio.aws.directconnect.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters._
final case class CreateDirectConnectGatewayAssociationProposalResponse(
    directConnectGatewayAssociationProposal: Option[
      zio.aws.directconnect.model.DirectConnectGatewayAssociationProposal
    ] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.directconnect.model.CreateDirectConnectGatewayAssociationProposalResponse = {
    import CreateDirectConnectGatewayAssociationProposalResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.directconnect.model.CreateDirectConnectGatewayAssociationProposalResponse
      .builder()
      .optionallyWith(
        directConnectGatewayAssociationProposal.map(value =>
          value.buildAwsValue()
        )
      )(_.directConnectGatewayAssociationProposal)
      .build()
  }
  def asReadOnly
      : zio.aws.directconnect.model.CreateDirectConnectGatewayAssociationProposalResponse.ReadOnly =
    zio.aws.directconnect.model.CreateDirectConnectGatewayAssociationProposalResponse
      .wrap(buildAwsValue())
}
object CreateDirectConnectGatewayAssociationProposalResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.directconnect.model.CreateDirectConnectGatewayAssociationProposalResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.directconnect.model.CreateDirectConnectGatewayAssociationProposalResponse =
      zio.aws.directconnect.model
        .CreateDirectConnectGatewayAssociationProposalResponse(
          directConnectGatewayAssociationProposal.map(value => value.asEditable)
        )
    def directConnectGatewayAssociationProposal: Option[
      zio.aws.directconnect.model.DirectConnectGatewayAssociationProposal.ReadOnly
    ]
    def getDirectConnectGatewayAssociationProposal: ZIO[
      Any,
      AwsError,
      zio.aws.directconnect.model.DirectConnectGatewayAssociationProposal.ReadOnly
    ] = AwsError.unwrapOptionField(
      "directConnectGatewayAssociationProposal",
      directConnectGatewayAssociationProposal
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.directconnect.model.CreateDirectConnectGatewayAssociationProposalResponse
  ) extends zio.aws.directconnect.model.CreateDirectConnectGatewayAssociationProposalResponse.ReadOnly {
    override val directConnectGatewayAssociationProposal: Option[
      zio.aws.directconnect.model.DirectConnectGatewayAssociationProposal.ReadOnly
    ] = scala
      .Option(impl.directConnectGatewayAssociationProposal())
      .map(value =>
        zio.aws.directconnect.model.DirectConnectGatewayAssociationProposal
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.directconnect.model.CreateDirectConnectGatewayAssociationProposalResponse
  ): zio.aws.directconnect.model.CreateDirectConnectGatewayAssociationProposalResponse.ReadOnly =
    new Wrapper(impl)
}

==> zio-aws-directconnect_2.12-5.17.267.6-sources.jar: zio/aws/directconnect/model/CreateDirectConnectGatewayAssociationProposalResponse.scala <==
package zio.aws.directconnect.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class CreateDirectConnectGatewayAssociationProposalResponse(
    directConnectGatewayAssociationProposal: Optional[
      zio.aws.directconnect.model.DirectConnectGatewayAssociationProposal
    ] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.directconnect.model.CreateDirectConnectGatewayAssociationProposalResponse = {
    import CreateDirectConnectGatewayAssociationProposalResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.directconnect.model.CreateDirectConnectGatewayAssociationProposalResponse
      .builder()
      .optionallyWith(
        directConnectGatewayAssociationProposal.map(value =>
          value.buildAwsValue()
        )
      )(_.directConnectGatewayAssociationProposal)
      .build()
  }
  def asReadOnly
      : zio.aws.directconnect.model.CreateDirectConnectGatewayAssociationProposalResponse.ReadOnly =
    zio.aws.directconnect.model.CreateDirectConnectGatewayAssociationProposalResponse
      .wrap(buildAwsValue())
}
object CreateDirectConnectGatewayAssociationProposalResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.directconnect.model.CreateDirectConnectGatewayAssociationProposalResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable
        : zio.aws.directconnect.model.CreateDirectConnectGatewayAssociationProposalResponse =
      zio.aws.directconnect.model
        .CreateDirectConnectGatewayAssociationProposalResponse(
          directConnectGatewayAssociationProposal.map(value => value.asEditable)
        )
    def directConnectGatewayAssociationProposal: Optional[
      zio.aws.directconnect.model.DirectConnectGatewayAssociationProposal.ReadOnly
    ]
    def getDirectConnectGatewayAssociationProposal: ZIO[
      Any,
      AwsError,
      zio.aws.directconnect.model.DirectConnectGatewayAssociationProposal.ReadOnly
    ] = AwsError.unwrapOptionField(
      "directConnectGatewayAssociationProposal",
      directConnectGatewayAssociationProposal
    )
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.directconnect.model.CreateDirectConnectGatewayAssociationProposalResponse
  ) extends zio.aws.directconnect.model.CreateDirectConnectGatewayAssociationProposalResponse.ReadOnly {
    override val directConnectGatewayAssociationProposal: Optional[
      zio.aws.directconnect.model.DirectConnectGatewayAssociationProposal.ReadOnly
    ] = zio.aws.core.internal
      .optionalFromNullable(impl.directConnectGatewayAssociationProposal())
      .map(value =>
        zio.aws.directconnect.model.DirectConnectGatewayAssociationProposal
          .wrap(value)
      )
  }
  def wrap(
      impl: software.amazon.awssdk.services.directconnect.model.CreateDirectConnectGatewayAssociationProposalResponse
  ): zio.aws.directconnect.model.CreateDirectConnectGatewayAssociationProposalResponse.ReadOnly =
    new Wrapper(impl)
}
